cloudsync.oauth
===============================================

.. autoclass:: cloudsync.oauth.OAuthConfig
   :members:
   :undoc-members:

.. autoclass:: cloudsync.oauth.OAuthProviderInfo
   :members:
   :undoc-members:
